==> formide-cli-0.1.19.tgz: package/lib/formide.js <==
/*
 *	    ____  ____  _____   ____________
 *	   / __ / __ /  _/ | / /_  __/ __
 *	  / /_/ / /_/ // //  |/ / / / / /_/ /
 *	 / ____/ _, _// // /|  / / / / _, _/
 *	/_/   /_/ |_/___/_/ |_/ /_/ /_/ |_|
 *
 */

/*
 *	Main CLI interface loader
 */

var argv 		= require('optimist').argv;
var colors 		= require('colors');
var Q 			= require('q');
var settings	= require('../package.json');

var TASKS = [

	{
		title: 'run',
		name: 'run',
		summary: 'Run the SDK environment',
		args: {
			'[OPTIONS]': ''
		},
		options: {
			'--port|-p': 'SDK environment HTTP port'
		}
	},

	{
		title: 'publish',
		name: 'publish',
		summary: 'Publish an app to apps.formide.com',
		options: {
			'--email|-e': 'Formide account email',
			'--password|-p': 'Formide account password'
		},
		alt: [ 'upload' ],
		module: './formide/publish'
	},

	{
		title: 'create',
		name: 'create',
		summary: 'Create a new formide.com app via the CLI wizard',
		options: {

		},
		module: './formide/create'
	},

	{
		title: 'help',
		name: 'help',
		summary: 'Provides help for a certain command',
		args: {
			'[command]': 'The command you desire help with'
		},
		module: './formide/help'
   	},

   	{
	   	title: 'login',
	   	name: 'login',
	   	summary: 'Setup your formide.com account locally',
	   	module: './formide/login'
   	},

   	{
	   	title: 'info',
	   	name: 'info',
	   	summary: 'Get info about the current project',
	   	module: './formide/info'
   	}
];

colors.setTheme({
	silly: 'rainbow',
	input: 'grey',
	small: 'grey',
	verbose: 'cyan',
	prompt: 'grey',
	info: 'white',
	data: 'grey',
	help: 'cyan',
	warn: 'yellow',
	debug: 'blue',
	error: 'red'
});

Formide = {

	// static
	//FORMIDE_API: 'https://api.formide.com',
	FORMIDE_API: 'http://api.formide.local',
	API_APPS: '/appdata/v1',
	API_AUTH: '/auth/v1',

	// functions
	_tryBuildingTask: function()
	{
		if(argv._.length === 0)
		{
			return false;
		}
		var taskName = argv._[0];
		return this._getTaskByName( taskName );
	},

	_getTaskByName: function( name )
	{
		for(var i = 0; i < TASKS.length; i++)
		{
			var t = TASKS[i];
			if(t.name === name)
			{
				return t;
			}
			if(t.alt)
			{
				for(var j = 0; j < t.alt.length; j++)
				{
					var alt = t.alt[j];
					if(alt === name)
					{
						return t;
					}
				}
			}
		}
	},

	_printAvailableTasks: function()
	{
		process.stderr.write('\nUsage: formide task args\n\n=======================\n\n');

	    if(process.argv.length > 2)
	    {
	    	process.stderr.write( (process.argv[2] + ' is not a valid task\n\n').bold.red );
	    }

	    process.stderr.write('Available tasks: '.bold);
	    process.stderr.write('(use --help or -h for more info)\n\n');

	    for(var i = 0; i < TASKS.length; i++)
	    {
			var task = TASKS[i];
			if(task.summary)
			{
				var name = '   ' + task.name + '  ';
				var dots = '';
				while((name + dots).length < 20)
				{
				  	dots += '.';
				}
				process.stderr.write(name.green.bold + dots.grey + '  ' + task.summary.bold + '\n');
			}
	    }

	    process.stderr.write('\n');
	},

	_printHelpLines: function()
	{
		process.stderr.write('\n=======================\n');

		for(var i = 0; i < TASKS.length; i++)
		{
			var task = TASKS[i];
			if( task.summary )
			{
				this._printUsage(task);
			}
		}

		process.stderr.write('\n');
	},

	_printVersionWarning: function()
	{
		if( this.npmVersion && this.npmVersion != settings.version.trim() )
		{
			process.stdout.write('\n------------------------------------\n'.red);
			process.stdout.write('Formide CLI is out of date:\n'.bold.yellow);
			process.stdout.write( (' * Locally installed version: ' + settings.version + '\n').yellow );
			process.stdout.write( (' * Latest version: ' + this.npmVersion + '\n').yellow );
			process.stdout.write( ' * Run '.yellow + 'npm install -g formide-cli'.bold + ' to update\n'.yellow );
			process.stdout.write('------------------------------------\n\n'.red);
			this.npmVersion = null;
		}
	},

	_printUsage: function( task )
	{
		var w = function( s )
		{
			process.stdout.write( s );
		};

		w('\n');

		var rightColumn = 41;
		var dots = '';
		var indent = '';
		var x, arg;

		var taskArgs = task.title;

		for(arg in task.args)
		{
			taskArgs += ' ' + arg;
    	}

		w(taskArgs.green.bold);

		while( (taskArgs + dots).length < rightColumn + 1)
		{
			dots += '.';
    	}

    	w(' ' + dots.grey + '  ');

    	if( task.summary )
    	{
			w(task.summary.bold);
    	}

    	for( arg in task.args )
    	{
	    	if( !task.args[arg] ) continue;

	    	indent = '';
			w('\n');

			while( indent.length < rightColumn )
			{
				indent += ' ';
			}

			w( (indent + '    ' + arg + ' ').bold );

			var argDescs = task.args[arg].split('\n');
			var argIndent = indent + '    ';

			for(x=0; x<arg.length + 1; x++)
			{
				argIndent += ' ';
      		}

      		for(x=0; x<argDescs.length; x++)
      		{
	  			if(x===0)
	  			{
	  				w( argDescs[x].bold );
        		}
        		else
        		{
					w( '\n' + argIndent + argDescs[x].bold );
        		}
      		}
    	}

    	indent = '';
		while(indent.length < task.name.length + 1)
		{
			indent += ' ';
    	}

    	var optIndent = indent;
    	while(optIndent.length < rightColumn + 4)
    	{
			optIndent += ' ';
    	}

    	for(var opt in task.options)
    	{
			w('\n');
			dots = '';

			var optLine = indent + '[' + opt + ']  ';

			w(optLine.yellow.bold);

			if(task.options[opt])
			{
				while( (dots.length + optLine.length - 2) < rightColumn)
				{
					dots += '.';
        		}
				w(dots.grey + '  ');

				var optDescs = task.options[opt].split('\n');
				for(x=0; x<optDescs.length; x++)
				{
					if(x===0)
					{
						w( optDescs[x].bold );
          			}
          			else
          			{
		  				w( '\n' + optIndent + optDescs[x].bold );
          			}
        		}
      		}
    	}

		w('\n');
	},

	run: function()
	{
		var self = this;

		self.checkLatestVersion();

		if( (argv.version || argv.v) && !argv._.length )
		{
			return this.version();
		}

		if( argv.help || argv.h )
		{
			return this._printHelpLines();
		}

		var taskSetting = this._tryBuildingTask();

		if( !taskSetting )
		{
			return this._printAvailableTasks();
		}

		var taskModule = require(taskSetting.module).FormideTask;

		var taskInstance = new taskModule();
		taskInstance.run(this);
	},

	version: function()
	{
		process.stderr.write( settings.version + '\n');
	},

	checkLatestVersion: function()
	{
		this.latestVersion = Q.defer( settings );
		var self = this;

		try
		{
			if( settings.version.indexOf('beta') > -1 )
			{
				self.latestVersion.resolve();
				return;
			}

			var FormideStore = require('./formide/store.js').FormideStore;
			var formideConfig = new FormideStore('formide.config');
			var versionCheck = formideConfig.get('versionCheck');

			if(versionCheck && ((versionCheck + 86400000) > Date.now() ))
			{
				// we've recently checked for the latest version, so don't bother again
				self.latestVersion.resolve();
				//return;
      		}

			var proxy = process.env.PROXY || process.env.http_proxy || null;
			var request = require('request');

			request({
				url: 'http://registry.npmjs.org/formide-cli/latest',
				proxy: proxy
			}, function( err, res, body )
			{
				try
				{
					self.npmVersion = JSON.parse( body ).version;
					formideConfig.set( 'versionCheck', Date.now() );
					formideConfig.save();
					self._printVersionWarning();
				}
				catch( e )
				{
					self.latestVersion.resolve();
				}
			});
		}
		catch( e )
		{
			self.latestVersion.resolve();
    	}
	},

	fail: function(msg, taskHelp)
	{
    	this.hasFailed = true;
		if(msg)
		{
			process.stderr.write(msg.error.bold);
			process.stderr.write( (' (Formide CLI v' + settings.version + ')').error.bold + '\n');
    	}

		if(taskHelp)
		{
			for(var i = 0; i < TASKS.length; i++)
			{
				var task = TASKS[i];
				if(task.name == taskHelp)
				{
					this.printUsage(task);
					process.stderr.write('\n');
	          		break;
	        	}
	      	}
	    }

		process.stderr.write('\n');
		process.exit(1);
  	},
}

exports.Formide = Formide;

==> formide-cli-0.1.20.tgz: package/lib/formide.js <==
/*
 *	    ____  ____  _____   ____________
 *	   / __ / __ /  _/ | / /_  __/ __
 *	  / /_/ / /_/ // //  |/ / / / / /_/ /
 *	 / ____/ _, _// // /|  / / / / _, _/
 *	/_/   /_/ |_/___/_/ |_/ /_/ /_/ |_|
 *
 */

/*
 *	Main CLI interface loader
 */

var argv 		= require('optimist').argv;
var colors 		= require('colors');
var Q 			= require('q');
var settings	= require('../package.json');

var TASKS = [

	{
		title: 'run',
		name: 'run',
		summary: 'Run the SDK environment',
		args: {
			'[OPTIONS]': ''
		},
		options: {
			'--port|-p': 'SDK environment HTTP port'
		}
	},

	{
		title: 'publish',
		name: 'publish',
		summary: 'Publish an app to apps.formide.com',
		options: {
			'--email|-e': 'Formide account email',
			'--password|-p': 'Formide account password'
		},
		alt: [ 'upload' ],
		module: './formide/publish'
	},

	{
		title: 'create',
		name: 'create',
		summary: 'Create a new formide.com app via the CLI wizard',
		options: {

		},
		module: './formide/create'
	},

	{
		title: 'help',
		name: 'help',
		summary: 'Provides help for a certain command',
		args: {
			'[command]': 'The command you desire help with'
		},
		module: './formide/help'
   	},

   	{
	   	title: 'login',
	   	name: 'login',
	   	summary: 'Setup your formide.com account locally',
	   	module: './formide/login'
   	},

   	{
	   	title: 'info',
	   	name: 'info',
	   	summary: 'Get info about the current project',
	   	module: './formide/info'
   	}
];

colors.setTheme({
	silly: 'rainbow',
	input: 'grey',
	small: 'grey',
	verbose: 'cyan',
	prompt: 'grey',
	info: 'white',
	data: 'grey',
	help: 'cyan',
	warn: 'yellow',
	debug: 'blue',
	error: 'red'
});

Formide = {

	// static
	FORMIDE_API: 'https://api.formide.com',
	//FORMIDE_API: 'http://api.formide.local',
	API_APPS: '/appdata/v1',
	API_AUTH: '/auth/v1',

	// functions
	_tryBuildingTask: function()
	{
		if(argv._.length === 0)
		{
			return false;
		}
		var taskName = argv._[0];
		return this._getTaskByName( taskName );
	},

	_getTaskByName: function( name )
	{
		for(var i = 0; i < TASKS.length; i++)
		{
			var t = TASKS[i];
			if(t.name === name)
			{
				return t;
			}
			if(t.alt)
			{
				for(var j = 0; j < t.alt.length; j++)
				{
					var alt = t.alt[j];
					if(alt === name)
					{
						return t;
					}
				}
			}
		}
	},

	_printAvailableTasks: function()
	{
		process.stderr.write('\nUsage: formide task args\n\n=======================\n\n');

	    if(process.argv.length > 2)
	    {
	    	process.stderr.write( (process.argv[2] + ' is not a valid task\n\n').bold.red );
	    }

	    process.stderr.write('Available tasks: '.bold);
	    process.stderr.write('(use --help or -h for more info)\n\n');

	    for(var i = 0; i < TASKS.length; i++)
	    {
			var task = TASKS[i];
			if(task.summary)
			{
				var name = '   ' + task.name + '  ';
				var dots = '';
				while((name + dots).length < 20)
				{
				  	dots += '.';
				}
				process.stderr.write(name.green.bold + dots.grey + '  ' + task.summary.bold + '\n');
			}
	    }

	    process.stderr.write('\n');
	},

	_printHelpLines: function()
	{
		process.stderr.write('\n=======================\n');

		for(var i = 0; i < TASKS.length; i++)
		{
			var task = TASKS[i];
			if( task.summary )
			{
				this._printUsage(task);
			}
		}

		process.stderr.write('\n');
	},

	_printVersionWarning: function()
	{
		if( this.npmVersion && this.npmVersion != settings.version.trim() )
		{
			process.stdout.write('\n------------------------------------\n'.red);
			process.stdout.write('Formide CLI is out of date:\n'.bold.yellow);
			process.stdout.write( (' * Locally installed version: ' + settings.version + '\n').yellow );
			process.stdout.write( (' * Latest version: ' + this.npmVersion + '\n').yellow );
			process.stdout.write( ' * Run '.yellow + 'npm install -g formide-cli'.bold + ' to update\n'.yellow );
			process.stdout.write('------------------------------------\n\n'.red);
			this.npmVersion = null;
		}
	},

	_printUsage: function( task )
	{
		var w = function( s )
		{
			process.stdout.write( s );
		};

		w('\n');

		var rightColumn = 41;
		var dots = '';
		var indent = '';
		var x, arg;

		var taskArgs = task.title;

		for(arg in task.args)
		{
			taskArgs += ' ' + arg;
    	}

		w(taskArgs.green.bold);

		while( (taskArgs + dots).length < rightColumn + 1)
		{
			dots += '.';
    	}

    	w(' ' + dots.grey + '  ');

    	if( task.summary )
    	{
			w(task.summary.bold);
    	}

    	for( arg in task.args )
    	{
	    	if( !task.args[arg] ) continue;

	    	indent = '';
			w('\n');

			while( indent.length < rightColumn )
			{
				indent += ' ';
			}

			w( (indent + '    ' + arg + ' ').bold );

			var argDescs = task.args[arg].split('\n');
			var argIndent = indent + '    ';

			for(x=0; x<arg.length + 1; x++)
			{
				argIndent += ' ';
      		}

      		for(x=0; x<argDescs.length; x++)
      		{
	  			if(x===0)
	  			{
	  				w( argDescs[x].bold );
        		}
        		else
        		{
					w( '\n' + argIndent + argDescs[x].bold );
        		}
      		}
    	}

    	indent = '';
		while(indent.length < task.name.length + 1)
		{
			indent += ' ';
    	}

    	var optIndent = indent;
    	while(optIndent.length < rightColumn + 4)
    	{
			optIndent += ' ';
    	}

    	for(var opt in task.options)
    	{
			w('\n');
			dots = '';

			var optLine = indent + '[' + opt + ']  ';

			w(optLine.yellow.bold);

			if(task.options[opt])
			{
				while( (dots.length + optLine.length - 2) < rightColumn)
				{
					dots += '.';
        		}
				w(dots.grey + '  ');

				var optDescs = task.options[opt].split('\n');
				for(x=0; x<optDescs.length; x++)
				{
					if(x===0)
					{
						w( optDescs[x].bold );
          			}
          			else
          			{
		  				w( '\n' + optIndent + optDescs[x].bold );
          			}
        		}
      		}
    	}

		w('\n');
	},

	run: function()
	{
		var self = this;

		self.checkLatestVersion();

		if( (argv.version || argv.v) && !argv._.length )
		{
			return this.version();
		}

		if( argv.help || argv.h )
		{
			return this._printHelpLines();
		}

		var taskSetting = this._tryBuildingTask();

		if( !taskSetting )
		{
			return this._printAvailableTasks();
		}

		var taskModule = require(taskSetting.module).FormideTask;

		var taskInstance = new taskModule();
		taskInstance.run(this);
	},

	version: function()
	{
		process.stderr.write( settings.version + '\n');
	},

	checkLatestVersion: function()
	{
		this.latestVersion = Q.defer( settings );
		var self = this;

		try
		{
			if( settings.version.indexOf('beta') > -1 )
			{
				self.latestVersion.resolve();
				return;
			}

			var FormideStore = require('./formide/store.js').FormideStore;
			var formideConfig = new FormideStore('formide.config');
			var versionCheck = formideConfig.get('versionCheck');

			if(versionCheck && ((versionCheck + 86400000) > Date.now() ))
			{
				// we've recently checked for the latest version, so don't bother again
				self.latestVersion.resolve();
				//return;
      		}

			var proxy = process.env.PROXY || process.env.http_proxy || null;
			var request = require('request');

			request({
				url: 'http://registry.npmjs.org/formide-cli/latest',
				proxy: proxy
			}, function( err, res, body )
			{
				try
				{
					self.npmVersion = JSON.parse( body ).version;
					formideConfig.set( 'versionCheck', Date.now() );
					formideConfig.save();
					self._printVersionWarning();
				}
				catch( e )
				{
					self.latestVersion.resolve();
				}
			});
		}
		catch( e )
		{
			self.latestVersion.resolve();
    	}
	},

	fail: function(msg, taskHelp)
	{
    	this.hasFailed = true;
		if(msg)
		{
			process.stderr.write(msg.error.bold);
			process.stderr.write( (' (Formide CLI v' + settings.version + ')').error.bold + '\n');
    	}

		if(taskHelp)
		{
			for(var i = 0; i < TASKS.length; i++)
			{
				var task = TASKS[i];
				if(task.name == taskHelp)
				{
					this.printUsage(task);
					process.stderr.write('\n');
	          		break;
	        	}
	      	}
	    }

		process.stderr.write('\n');
		process.exit(1);
  	},
}

exports.Formide = Formide;
